from face_recognition import load_image_file, face_encodings, compare_faces
import os


def load_and_encode_image(image_path):
    image = load_image_file(image_path)
    encodings = face_encodings(image)
    if encodings:
        return encodings[0]
    else:
        raise ValueError("No faces found in the image!")


def recognize_faces(known_face_encodings, image_path_to_check):
    image_to_check = load_image_file(image_path_to_check)
    encodings_to_check = face_encodings(image_to_check)
    for face_encoding in encodings_to_check:
        matches = compare_faces(known_face_encodings, face_encoding)
        if True in matches:
            return True
    return False




from setuptools import setup, find_packages


setup(
    name="face_genius",
    version="0.2.1",
    packages=find_packages(),
    install_requires=[
        "face_recognition",
        "numpy"
    ],
    author="Victor Tkachev",
    author_email="vic.tkachev@gmail.com",
    description="A simple face recognition example package",
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/NeuronsUII/LizaAlert_n",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
